# Fi18n

A simple and lightweight package to manage translations in your Flutter project. 
This package use code generation to bring you compile time error for untranslated strings. 

### Features

- [x] Write your translations in .arb files
- [x] Compile time error for untranslated strings
- [x] Access the current translations without Flutter `Context`
- [x] Configure locale fallback to be used in case the user select an unsupported locale


### Install

1. Register the dependency in your `pubspec.yaml`

```yaml
dependencies:
  fi18n:
```

2. Create a `build.yaml` in the project folder. Here we need to tell the package witch default locale we want to use.
Change `en` to the default locale name you want to use it must follow the 
languageCode or languageCode_CountryCode format i.e: `en`, `en_US`, `pt`, `pt_BR`.

```yaml
targets:
  $default:
    builders:
      fi18n|arb_builder:
        options:
          default_locale: en
```

If not specified it defaults to `en`. This is where this library will use as the base locale
all the locales must exist in these locale file.

3. Create your `.arb` files in `lib/res`. 

These files must follow some rules:

- All your files that need translation must be placed in this directory in order to Fi18n have access to it.
- The translation file name can me anything but it must follow this pattern:
  - End with `.arb` extension
  - Contains the language code (required): `filename_en.arb`
  - Contains language code + country code (optional): `filename_en_US.arb`  


This is an example of a valid `.arb` witch have the file name as `filename_en.arb` in the `lib/res` directory:

````json
{
  "hello": "World",
  "world": "World",
  "firstName": "First Name"
}
````

4. The latest step is to run the code generation tool. Write the following command to generate the required code: `flutter pub run build_runner build`.
This will generate the `fi18n.dart` file in `lib/res/`.

5. Use the generated `S` class to access your translations.

```dart
class MyHomePage extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(S.of(context).helloWorld),
      ), 
    );
  }
}
```


### Note

- It is a error if your project doesn't have a translation file for the default local specified in the `build.yaml`.
- To let Fi18n watch for changes in your translation files in realtime run `flutter pub run build_runner watch`. 
With this every time you change the `.arb` files the translation Dart code will be available to use.  